Module fastboot

Module fastboot 

Fastboot operations via the fastboot CLI tool.

The fastboot protocol is completely separate from ADB and requires the fastboot binary (part of Android platform-tools). There is currently no pure-Rust fastboot library, so this module shells out to the fastboot binary.

Structs

FastbootManager
Executes fastboot operations by shelling out to the fastboot binary.

Enums

FastbootCommand
Fastboot commands that require the fastboot binary.
FastbootError
Errors from fastboot operations.

Type Aliases

FastbootResult